==> haskell-wai-handler-launch-3.0.2.4-51-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wai-handler-launch.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-handler-launch
version: 3.0.2.4
id: wai-handler-launch-3.0.2.4-G5uopTr9yt5ZGb7uuUa8E
key: wai-handler-launch-3.0.2.4-G5uopTr9yt5ZGb7uuUa8E
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
synopsis: Launch a web app in the default browser.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-handler-launch>.
category: Web
abi: 4410f1a9d275a41b599de819284f1ba4
exposed: True
exposed-modules:
    Network.Wai.Handler.Launch
import-dirs: /usr/lib/ghc-8.4.3/site-local/wai-handler-launch-3.0.2.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/wai-handler-launch-3.0.2.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/wai-handler-launch-3.0.2.4
hs-libraries: HSwai-handler-launch-3.0.2.4-G5uopTr9yt5ZGb7uuUa8E
depends:
    async-2.2.1-B6m2kYywRJu7nicgTBxsJe base-4.11.1.0
    bytestring-0.10.8.2 http-types-0.12.1-II9Izt8nVfhCfceL6igA2T
    process-1.6.3.0 streaming-commons-0.2.1.0-2y3UhC0AAPrCaYwZozhK9I
    transformers-0.5.5.0 wai-3.2.1.2-7nYsHZjqYhMEbD0T7qy1Zf
    warp-3.2.23-7B23bqS4cOdF7EzqtLelbk
abi-depends: async-2.2.1-B6m2kYywRJu7nicgTBxsJe=32776142fda961cc693aa4db742773f9
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             http-types-0.12.1-II9Izt8nVfhCfceL6igA2T=b23e50a639b630c1d82e921bfca06775
             process-1.6.3.0=b58285e21ceee9f67d7be28ddb8b2627
             streaming-commons-0.2.1.0-2y3UhC0AAPrCaYwZozhK9I=d02eb8f4075c36aa63e714831eccd502
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             wai-3.2.1.2-7nYsHZjqYhMEbD0T7qy1Zf=91ba5164ada377f7d55099a2359e2c5a
             warp-3.2.23-7B23bqS4cOdF7EzqtLelbk=dfc818e6634940e9c8129fd589390168
haddock-interfaces: /usr/share/doc/haskell-wai-handler-launch/html/wai-handler-launch.haddock
haddock-html: /usr/share/doc/haskell-wai-handler-launch/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-handler-launch-3.0.2.4-53-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wai-handler-launch.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-handler-launch
version: 3.0.2.4
id: wai-handler-launch-3.0.2.4-RHifWzpAlAL3jUDnYRfRG
key: wai-handler-launch-3.0.2.4-RHifWzpAlAL3jUDnYRfRG
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
synopsis: Launch a web app in the default browser.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-handler-launch>.
category: Web
abi: 2f086b713a8f1d50aa5c6946ff8774b6
exposed: True
exposed-modules:
    Network.Wai.Handler.Launch
import-dirs: /usr/lib/ghc-8.4.3/site-local/wai-handler-launch-3.0.2.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/wai-handler-launch-3.0.2.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/wai-handler-launch-3.0.2.4
hs-libraries: HSwai-handler-launch-3.0.2.4-RHifWzpAlAL3jUDnYRfRG
depends:
    async-2.2.1-B6m2kYywRJu7nicgTBxsJe base-4.11.1.0
    bytestring-0.10.8.2 http-types-0.12.1-II9Izt8nVfhCfceL6igA2T
    process-1.6.3.0 streaming-commons-0.2.1.0-2y3UhC0AAPrCaYwZozhK9I
    transformers-0.5.5.0 wai-3.2.1.2-7nYsHZjqYhMEbD0T7qy1Zf
    warp-3.2.23-IWiWJvudCGxJ1ocDsVuKFW
abi-depends: async-2.2.1-B6m2kYywRJu7nicgTBxsJe=32776142fda961cc693aa4db742773f9
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             http-types-0.12.1-II9Izt8nVfhCfceL6igA2T=b23e50a639b630c1d82e921bfca06775
             process-1.6.3.0=b58285e21ceee9f67d7be28ddb8b2627
             streaming-commons-0.2.1.0-2y3UhC0AAPrCaYwZozhK9I=d02eb8f4075c36aa63e714831eccd502
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             wai-3.2.1.2-7nYsHZjqYhMEbD0T7qy1Zf=91ba5164ada377f7d55099a2359e2c5a
             warp-3.2.23-IWiWJvudCGxJ1ocDsVuKFW=31d1d20026b0e4505213bb0775d373d4
haddock-interfaces: /usr/share/doc/haskell-wai-handler-launch/html/wai-handler-launch.haddock
haddock-html: /usr/share/doc/haskell-wai-handler-launch/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
